@@ -460,11 +460,12 @@ def instance(request, host_id, vname):
         vcpu_host = len(vcpu_range)
         telnet_port = conn.get_telnet_port()
         vnc_port = conn.get_vnc_port()
-        vnc_keymap = conn.get_vnc_keymap
+        vnc_keymap = conn.get_vnc_keymap()
         snapshots = sorted(conn.get_snapshot(), reverse=True)
         inst_xml = conn._XMLDesc(VIR_DOMAIN_XML_SECURE)
         has_managed_save_image = conn.get_managed_save_image()
         clone_disks = show_clone_disk(disks)
+        vnc_passwd = conn.get_vnc_passwd()
     except libvirtError as err:
         errors.append(err)
 
@@ -551,6 +552,8 @@ def instance(request, host_id, vname):
                 else:
                     passwd = request.POST.get('vnc_passwd', '')
                     clear = request.POST.get('clear_pass', False)
+                    if clear:
+                        passwd = ''
                     if not passwd and not clear:
                         msg = _("Enter the VNC password or select Generate")
                         errors.append(msg)
@@ -570,13 +573,14 @@ def instance(request, host_id, vname):
             if 'migrate' in request.POST:
                 compute_id = request.POST.get('compute_id', '')
                 live = request.POST.get('live_migrate', False)
+                unsafe = request.POST.get('unsafe_migrate', False)
                 xml_del = request.POST.get('xml_delete', False)
                 new_compute = Compute.objects.get(id=compute_id)
                 conn_migrate = wvmInstances(new_compute.hostname,
                                             new_compute.login,
                                             new_compute.password,
                                             new_compute.type)
-                conn_migrate.moveto(conn, vname, live, xml_del)
+                conn_migrate.moveto(conn, vname, live, unsafe, xml_del)
                 conn_migrate.define_move(vname)
                 conn_migrate.close()
                 return HttpResponseRedirect('/instance/%s/%s' % (compute_id, vname))
