@@ -3,7 +3,7 @@
 #
 import time
 import os.path
-from libvirt import libvirtError, VIR_DOMAIN_XML_SECURE, VIR_MIGRATE_LIVE
+from libvirt import libvirtError, VIR_DOMAIN_XML_SECURE, VIR_MIGRATE_LIVE, VIR_MIGRATE_UNSAFE
 from vrtManager import util
 from xml.etree import ElementTree
 from datetime import datetime
@@ -65,10 +65,12 @@ class wvmInstances(wvmConnect):
         dom = self.get_instance(name)
         dom.resume()
 
-    def moveto(self, conn, name, live, undefine):
+    def moveto(self, conn, name, live, unsafe, undefine):
         flags = 0
         if live and conn.get_status() == 1:
             flags |= VIR_MIGRATE_LIVE
+        if unsafe and conn.get_status() == 1:
+            flags |= VIR_MIGRATE_UNSAFE
         dom = conn.get_instance(name)
         dom.migrate(self.wvm, flags, name, None, 0)
         if undefine:
@@ -386,7 +388,11 @@ class wvmInstance(wvmConnect):
     def set_vnc_passwd(self, passwd):
         xml = self._XMLDesc(VIR_DOMAIN_XML_SECURE)
         root = ElementTree.fromstring(xml)
-        graphics_vnc = root.find("devices/graphics[@type='vnc']")
+        try:
+            graphics_vnc = root.find("devices/graphics[@type='vnc']")
+        except SyntaxError:
+            # Little fix for old version ElementTree
+            graphics_vnc = root.find("devices/graphics")
         if passwd:
             graphics_vnc.set('passwd', passwd)
         else:
@@ -394,13 +400,17 @@ class wvmInstance(wvmConnect):
                 graphics_vnc.attrib.pop('passwd')
             except:
                 pass
-        newxml = ElementTree.tostring(root, encoding='utf-8', method='xml')
+        newxml = ElementTree.tostring(root)
         self._defineXML(newxml)
 
     def set_vnc_keymap(self, keymap):
         xml = self._XMLDesc(VIR_DOMAIN_XML_SECURE)
         root = ElementTree.fromstring(xml)
-        graphics_vnc = root.find("devices/graphics[@type='vnc']")
+        try:
+            graphics_vnc = root.find("devices/graphics[@type='vnc']")
+        except SyntaxError:
+            # Little fix for old version ElementTree
+            graphics_vnc = root.find("devices/graphics")
         if keymap:
             graphics_vnc.set('keymap', keymap)
         else:
@@ -408,7 +418,7 @@ class wvmInstance(wvmConnect):
                 graphics_vnc.attrib.pop('keymap')
             except:
                 pass
-        newxml = ElementTree.tostring(root, encoding='utf-8', method='xml')
+        newxml = ElementTree.tostring(root)
         self._defineXML(newxml)
 
     def get_vnc_keymap(self):
@@ -508,6 +518,10 @@ class wvmInstance(wvmConnect):
         uuid = tree.find('uuid')
         tree.remove(uuid)
 
+        for num, net in enumerate(tree.findall('devices/interface')):
+            elm = net.find('mac')
+            elm.set('address', clone_data['net-' + str(num)])
+
         for disk in tree.findall('devices/disk'):
             if disk.get('device') == 'disk':
                 elm = disk.find('target')
