@@ -152,6 +152,26 @@ TIME_JS_REFRESH = 2000
 WS_PORT = 6080
 WS_HOST = '0.0.0.0'
 
+# keepalive interval and count for libvirt connections
+#
+# from: http://libvirt.org/html/libvirt-libvirt.html#virConnectSetKeepAlive
+#
+# Start sending keepalive messages after @interval seconds of inactivity and
+# consider the connection to be broken when no response is received after
+# @count keepalive messages sent in a row. In other words, sending count + 1
+# keepalive message results in closing the connection. When @interval is <= 0,
+# no keepalive messages will be sent. When @count is 0, the connection will be
+# automatically closed after @interval seconds of inactivity without sending
+# any keepalive messages.
+#
+# Keep in mind that by default (at least on ubuntu variants) the libvirt.d is
+# configured to send keepalive messages by default (interval: 5, count: 5).
+# If the libvirt.d keeps on sending keepalive messages form the server-side
+# we will never close the connection no matter what these parameters are set
+# to, as long as the libvirt.d is up and running at the server side.
+LIBVIRT_KEEPALIVE_INTERVAL = 5
+LIBVIRT_KEEPALIVE_COUNT    = 5
+
 # Installed Apps shouldn't be overridden
 INSTALLED_APPS = (
     'django.contrib.auth',
